@@ -2,7 +2,7 @@
 #
 #   strip.sh - Strip debugging symbols from binary files
 #
-#   Copyright (c) 2007-2018 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2007-2020 Pacman Development Team <pacman-dev@archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ build_id() {
 
 source_files() {
 	LANG=C readelf "$1" --debug-dump | \
-		awk '/DW_AT_name +:/{name=$8}/DW_AT_comp_dir +:/{{if (name !~ /^\//) {printf "%s/", $8}}{print name}}'
+		awk '/DW_AT_name +:/{name=$8}/DW_AT_comp_dir +:/{{if (name == "<artificial>") next}{if (name !~ /^[<\/]/) {printf "%s/", $8}}{print name}}'
 }
 
 strip_file() {
@@ -56,11 +56,14 @@ strip_file() {
 		fi
 
 		# copy source files to debug directory
-		local f t
-		while read -r t; do
-			f=${t/${dbgsrcdir}/"$srcdir"}
-			mkdir -p "${dbgsrc/"$dbgsrcdir"/}${t%/*}"
-			cp -- "$f" "${dbgsrc/"$dbgsrcdir"/}$t"
+		local file dest t
+		while IFS= read -r t; do
+			file=${t/${dbgsrcdir}/"$srcdir"}
+			dest="${dbgsrc/"$dbgsrcdir"/}$t"
+			if ! [[ -f $dest ]]; then
+				mkdir -p "${dest%/*}"
+				cp -- "$file" "$dest"
+			fi
 		done < <(source_files "$binary")
 
 		# copy debug symbols to debug directory
@@ -69,7 +72,7 @@ strip_file() {
 		objcopy --add-gnu-debuglink="$dbgdir/${binary#/}.debug" "$binary"
 
 		# create any needed hardlinks
-		while read -rd '' file ; do
+		while IFS= read -rd '' file ; do
 			if [[ "${binary}" -ef "${file}" && ! -f "$dbgdir/${file}.debug" ]]; then
 				mkdir -p "$dbgdir/${file%/*}"
 				ln "$dbgdir/${binary}.debug" "$dbgdir/${file}.debug"
@@ -110,8 +113,8 @@ tidy_strip() {
 		fi
 
 		local binary strip_flags
-		find . -type f -perm -u+w -print0 2>/dev/null | while read -rd '' binary ; do
-			case "$(file -bi "$binary")" in
+		find . -type f -perm -u+w -print0 2>/dev/null | while IFS= read -rd '' binary ; do
+			case "$(file -S -bi "$binary")" in
 				*application/x-sharedlib*)  # Libraries (.so)
 					strip_flags="$STRIP_SHARED";;
 				*application/x-archive*)    # Libraries (.a)
